Monzo API
=====================================

The Monzo API package allows you to interact with the API provided by Monzo
bank.

DISCLAIMER
-------------------------------------

Before using this package it is important to understand that the Monzo API should only be
used for non-public projects hosted securely. Please do not use this on a public server
and do not use it for accessing other users accounts.

Installation
-------------------------------------

The package can be installed as a standard pip project:


.. code-block:: bash

    pip install monzo-api

Basic Usage
-------------------------------------

Prior to using the API you need to obtain a few details from Monzo. Please
read `this <https://monzo-api.readthedocs.io/en/latest/monzo_setup.html>`_
document.

Please see the examples in the example directory.

Documentation
-------------------------------------

Full documentation can be found on
`Read The Docs <https://monzo-api.readthedocs.io>`_
